@@ -181,6 +181,10 @@ class RemoteAcquisitionControl(object):
         self.pkill_remote()
         time.sleep(1)
 
+        instance_settings = self.config_data["controllers"].get(
+            self.instance_name
+        )
+
         command_dict = {
             "-m": "rpi_camera_colony.acquisition",
             "--instance-name": self.instance_name,
@@ -199,17 +203,27 @@ class RemoteAcquisitionControl(object):
             "--log-level": self.config_data["log"]["level"],
             "--control-stream-ip": self.config_data["control"]["address"],
             "--control-stream-port": self.config_data["control"]["port"],
+            # "--stream-video": instance_settings["stream_video"],
         }
+        if instance_settings["stream_video"]:
+            stream_dict = {
+                "--stream-ip": instance_settings["stream_ip"],
+                "--stream-port": instance_settings["stream_port"],
+            }
+            command_dict.update(stream_dict)
+
+        cmd = self._make_pi_command_base_list()
+        cmd.append(self.remote_python_interpreter)
+        cmd += dict_to_list(validate_ssh_cli_kwargs(command_dict=command_dict))
+        cmd += ["--stream-video"]
 
-        cmd = self._make_pi_command_base_list() + [
-            self.remote_python_interpreter,
-            dict_to_list(validate_ssh_cli_kwargs(command_dict=command_dict)),
-        ]
         execute_in_commandline(cmd=cmd)
 
         logging.debug(
             f"Initialised remote acquisition controller for: {self.remote_address} known as: {self.instance_name}."
         )
+        logging.debug(command_dict)
+        logging.debug(f"CMD: {cmd}")
 
         self.connected = True
 
